@@ -1,7 +1,10 @@
 # -*- coding: UTF-8 -*-
+from .baudot import *
 from .dna import *
 from .dummy import *
+from .html import *
 from .markdown import *
 from .octal import *
 from .ordinal import *
 from .url import *
+
